@@ -202,7 +202,7 @@ class RsyncStreamIO(Exception):
 
 class NotStandalone(BzrError):
 
-    _format = '%(location) is not a standalone tree.'
+    _fmt = '%(location)s is not a standalone tree.'
     _internal = False
 
     def __init__(self, location):
