@@ -57,7 +57,8 @@ class DiffWriter(object):
         self.target = target
         self.lp = LineParser()
         self.chunks = []
-        self._read_colordiffrc()
+        self._read_colordiffrc('/etc/colordiffrc')
+        self._read_colordiffrc(expanduser('~/.colordiffrc'))
         self.added_leading_tabs = 0
         self.added_trailing_whitespace = 0
         self.spurious_whitespace = 0
@@ -67,8 +68,7 @@ class DiffWriter(object):
         self._old_lines = []
         self.check_style = check_style
 
-    def _read_colordiffrc(self):
-        path = expanduser('~/.colordiffrc')
+    def _read_colordiffrc(self, path):
         try:
             f = open(path, 'r')
         except IOError:
