@@ -21,23 +21,23 @@ class TestBzrTools(TestCaseWithTransport):
         self.touch('name~')
         assert os.path.lexists('name~')
         self.touch('name.pyc')
-        self.run_bzr('clean-tree')
+        self.run_bzr('clean-tree --force')
         assert os.path.lexists('name~')
         assert not os.path.lexists('name')
         self.touch('name')
-        self.run_bzr('clean-tree --detritus')
+        self.run_bzr('clean-tree --detritus --force')
         assert os.path.lexists('name')
         assert not os.path.lexists('name~')
         assert os.path.lexists('name.pyc')
-        self.run_bzr('clean-tree --ignored')
+        self.run_bzr('clean-tree --ignored --force')
         assert os.path.lexists('name')
         assert not os.path.lexists('name.pyc')
-        self.run_bzr('clean-tree --unknown')
+        self.run_bzr('clean-tree --unknown --force')
         assert not os.path.lexists('name')
         self.touch('name')
         self.touch('name~')
         self.touch('name.pyc')
-        self.run_bzr('clean-tree --unknown --ignored')
+        self.run_bzr('clean-tree --unknown --ignored --force')
         assert not os.path.lexists('name')
         assert not os.path.lexists('name~')
         assert not os.path.lexists('name.pyc')
