@@ -7,7 +7,7 @@ from bzrlib.plugins.bzrtools.hunk_selector import (
     UnshelveHunkSelector,
     )
 from bzrlib.plugins.bzrtools.errors import NoColor
-from bzrlib.plugins.bzrtools import cmd_shelf
+from bzrlib.plugins.bzrtools.command_classes import cmd_shelf
 
 
 class ShelfTests(bzrlib.tests.TestCaseWithTransport):
